//-*-c++-*-
#ifndef TULIP_COLORSPROXY_H
#define TULIP_COLORSPROXY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PropertyProxy.h"
#include "MethodFactory.h"
#include "TemplateFactory.h"
#include "Colors.h"

class PropertyContext;
/** \addtogroup properties */ 
/*@{*/
class TLP_SCOPE ColorsProxy:public PropertyProxy<ColorType,ColorType, Colors> { 
  friend class Colors;
public :
  ColorsProxy (SuperGraph *);
  ~ColorsProxy();
  PProxy* clonePrototype(SuperGraph *, std::string );
  void copy( const node, const node, PProxy * );
  void copy( const edge, const edge, PProxy * );
};
/*@}*/
#endif

